@@ -1,19 +1,32 @@
 import typing
 from .base_category import BaseCategory
-from vkbottle_types.responses import appWidgets, base
+from vkbottle_types.responses.appWidgets import (
+    AppWidgetsPhoto,
+    AppWidgetsPhotos,
+    GetAppImageUploadServerResponse,
+    GetAppImageUploadServerResponseModel,
+    GetAppImagesResponse,
+    GetGroupImageUploadServerResponse,
+    GetGroupImageUploadServerResponseModel,
+    GetGroupImagesResponse,
+    GetImagesByIdResponse,
+    SaveAppImageResponse,
+    SaveGroupImageResponse
+)
+from vkbottle_types.responses.base import OkResponse
 
 
 class AppWidgetsCategory(BaseCategory):
     async def get_app_image_upload_server(
         self, image_type: str, **kwargs
-    ) -> appWidgets.GetAppImageUploadServerResponseModel:
+    ) -> GetAppImageUploadServerResponseModel:
         """Returns a URL for uploading a photo to the community collection for community app widgets
         :param image_type:
         """
 
         params = self.get_set_params(locals())
         response = await self.api.request("appWidgets.getAppImageUploadServer", params)
-        model = appWidgets.GetAppImageUploadServerResponse
+        model = GetAppImageUploadServerResponse
         return model(**response).response
 
     async def get_app_images(
@@ -22,7 +35,7 @@ class AppWidgetsCategory(BaseCategory):
         count: typing.Optional[int] = None,
         image_type: typing.Optional[str] = None,
         **kwargs
-    ) -> appWidgets.AppWidgetsPhotos:
+    ) -> AppWidgetsPhotos:
         """Returns an app collection of images for community app widgets
         :param offset: Offset needed to return a specific subset of images.
         :param count: Maximum count of results.
@@ -31,19 +44,19 @@ class AppWidgetsCategory(BaseCategory):
 
         params = self.get_set_params(locals())
         response = await self.api.request("appWidgets.getAppImages", params)
-        model = appWidgets.GetAppImagesResponse
+        model = GetAppImagesResponse
         return model(**response).response
 
     async def get_group_image_upload_server(
         self, image_type: str, **kwargs
-    ) -> appWidgets.GetGroupImageUploadServerResponseModel:
+    ) -> GetGroupImageUploadServerResponseModel:
         """Returns a URL for uploading a photo to the community collection for community app widgets
         :param image_type:
         """
 
         params = self.get_set_params(locals())
         response = await self.api.request("appWidgets.getGroupImageUploadServer", params)
-        model = appWidgets.GetGroupImageUploadServerResponse
+        model = GetGroupImageUploadServerResponse
         return model(**response).response
 
     async def get_group_images(
@@ -52,7 +65,7 @@ class AppWidgetsCategory(BaseCategory):
         count: typing.Optional[int] = None,
         image_type: typing.Optional[str] = None,
         **kwargs
-    ) -> appWidgets.AppWidgetsPhotos:
+    ) -> AppWidgetsPhotos:
         """Returns a community collection of images for community app widgets
         :param offset: Offset needed to return a specific subset of images.
         :param count: Maximum count of results.
@@ -61,24 +74,24 @@ class AppWidgetsCategory(BaseCategory):
 
         params = self.get_set_params(locals())
         response = await self.api.request("appWidgets.getGroupImages", params)
-        model = appWidgets.GetGroupImagesResponse
+        model = GetGroupImagesResponse
         return model(**response).response
 
     async def get_images_by_id(
         self, images: typing.List[str], **kwargs
-    ) -> typing.List[appWidgets.AppWidgetsPhoto]:
+    ) -> typing.List[AppWidgetsPhoto]:
         """Returns an image for community app widgets by its ID
         :param images: List of images IDs
         """
 
         params = self.get_set_params(locals())
         response = await self.api.request("appWidgets.getImagesById", params)
-        model = appWidgets.GetImagesByIdResponse
+        model = GetImagesByIdResponse
         return model(**response).response
 
     async def save_app_image(
         self, hash: str, image: str, **kwargs
-    ) -> appWidgets.AppWidgetsPhoto:
+    ) -> AppWidgetsPhoto:
         """Allows to save image into app collection for community app widgets
         :param hash: Parameter returned when photo is uploaded to server
         :param image: Parameter returned when photo is uploaded to server
@@ -86,12 +99,12 @@ class AppWidgetsCategory(BaseCategory):
 
         params = self.get_set_params(locals())
         response = await self.api.request("appWidgets.saveAppImage", params)
-        model = appWidgets.SaveAppImageResponse
+        model = SaveAppImageResponse
         return model(**response).response
 
     async def save_group_image(
         self, hash: str, image: str, **kwargs
-    ) -> appWidgets.AppWidgetsPhoto:
+    ) -> AppWidgetsPhoto:
         """Allows to save image into community collection for community app widgets
         :param hash: Parameter returned when photo is uploaded to server
         :param image: Parameter returned when photo is uploaded to server
@@ -99,7 +112,7 @@ class AppWidgetsCategory(BaseCategory):
 
         params = self.get_set_params(locals())
         response = await self.api.request("appWidgets.saveGroupImage", params)
-        model = appWidgets.SaveGroupImageResponse
+        model = SaveGroupImageResponse
         return model(**response).response
 
     async def update(
@@ -112,5 +125,5 @@ class AppWidgetsCategory(BaseCategory):
 
         params = self.get_set_params(locals())
         response = await self.api.request("appWidgets.update", params)
-        model = base.OkResponse
+        model = OkResponse
         return model(**response).response
