@@ -1,19 +1,33 @@
 import typing
 from .base_category import BaseCategory
-from vkbottle_types.responses import base, utils
+from vkbottle_types.responses.utils import (
+    CheckLinkResponse,
+    GetLastShortenedLinksResponse,
+    GetLastShortenedLinksResponseModel,
+    GetLinkStatsExtendedResponse,
+    GetLinkStatsResponse,
+    GetServerTimeResponse,
+    GetShortLinkResponse,
+    ResolveScreenNameResponse,
+    UtilsDomainResolved,
+    UtilsLinkChecked,
+    UtilsLinkStats,
+    UtilsShortLink
+)
+from vkbottle_types.responses.base import OkResponse
 
 
 class UtilsCategory(BaseCategory):
     async def check_link(
         self, url: str, **kwargs
-    ) -> utils.UtilsLinkChecked:
+    ) -> UtilsLinkChecked:
         """Checks whether a link is blocked in VK.
         :param url: Link to check (e.g., 'http://google.com').
         """
 
         params = self.get_set_params(locals())
         response = await self.api.request("utils.checkLink", params)
-        model = utils.CheckLinkResponse
+        model = CheckLinkResponse
         return model(**response).response
 
     async def delete_from_last_shortened(
@@ -25,7 +39,7 @@ class UtilsCategory(BaseCategory):
 
         params = self.get_set_params(locals())
         response = await self.api.request("utils.deleteFromLastShortened", params)
-        model = base.OkResponse
+        model = OkResponse
         return model(**response).response
 
     async def get_last_shortened_links(
@@ -33,7 +47,7 @@ class UtilsCategory(BaseCategory):
         count: typing.Optional[int] = None,
         offset: typing.Optional[int] = None,
         **kwargs
-    ) -> utils.GetLastShortenedLinksResponseModel:
+    ) -> GetLastShortenedLinksResponseModel:
         """Returns a list of user's shortened links.
         :param count: Number of links to return.
         :param offset: Offset needed to return a specific subset of links.
@@ -41,7 +55,7 @@ class UtilsCategory(BaseCategory):
 
         params = self.get_set_params(locals())
         response = await self.api.request("utils.getLastShortenedLinks", params)
-        model = utils.GetLastShortenedLinksResponse
+        model = GetLastShortenedLinksResponse
         return model(**response).response
 
     async def get_link_stats(
@@ -53,7 +67,7 @@ class UtilsCategory(BaseCategory):
         intervals_count: typing.Optional[int] = None,
         extended: typing.Optional[bool] = None,
         **kwargs
-    ) -> utils.UtilsLinkStats:
+    ) -> UtilsLinkStats:
         """Returns stats data for shortened link.
         :param key: Link key (characters after vk.cc/).
         :param source: Source of scope
@@ -66,8 +80,8 @@ class UtilsCategory(BaseCategory):
         params = self.get_set_params(locals())
         response = await self.api.request("utils.getLinkStats", params)
         model = self.get_model(
-            {("extended",): utils.GetLinkStatsExtendedResponse},
-            default=utils.GetLinkStatsResponse,
+            {("extended",): GetLinkStatsExtendedResponse},
+            default=GetLinkStatsResponse,
             params=params,
         )
         return model(**response).response
@@ -79,12 +93,12 @@ class UtilsCategory(BaseCategory):
 
         params = self.get_set_params(locals())
         response = await self.api.request("utils.getServerTime", params)
-        model = utils.GetServerTimeResponse
+        model = GetServerTimeResponse
         return model(**response).response
 
     async def get_short_link(
         self, url: str, private: typing.Optional[bool] = None, **kwargs
-    ) -> utils.UtilsShortLink:
+    ) -> UtilsShortLink:
         """Allows to receive a link shortened via vk.cc.
         :param url: URL to be shortened.
         :param private: 1 — private stats, 0 — public stats.
@@ -92,17 +106,17 @@ class UtilsCategory(BaseCategory):
 
         params = self.get_set_params(locals())
         response = await self.api.request("utils.getShortLink", params)
-        model = utils.GetShortLinkResponse
+        model = GetShortLinkResponse
         return model(**response).response
 
     async def resolve_screen_name(
         self, screen_name: str, **kwargs
-    ) -> utils.UtilsDomainResolved:
+    ) -> UtilsDomainResolved:
         """Detects a type of object (e.g., user, community, application) and its ID by screen name.
         :param screen_name: Screen name of the user, community (e.g., 'apiclub,' 'andrew', or 'rules_of_war'), or application.
         """
 
         params = self.get_set_params(locals())
         response = await self.api.request("utils.resolveScreenName", params)
-        model = utils.ResolveScreenNameResponse
+        model = ResolveScreenNameResponse
         return model(**response).response
