@@ -23,7 +23,7 @@ from vkbottle_types.objects import (
     MessagesPinnedMessage,
     MessagesSendUserIdsResponseItem,
     UsersUser,
-    UsersUserFull
+    UsersUserFull,
 )
 
 
@@ -175,8 +175,8 @@ class SendUserIdsResponse(BaseResponse):
     response: typing.List["MessagesSendUserIdsResponseItem"] = None
 
 
-class SendPeerIdsResponse(BaseResponse):
-    response: typing.List["MessagesSendUserIdsResponseItem"] = None
+class SendPeerIdsResponse(SendUserIdsResponse):
+    pass
 
 
 class SetChatPhotoResponse(BaseResponse):
